@@ -66,7 +66,9 @@ enum
   PROP_ADDRESS_TYPE
 };
 
-#define UNIX_PATH_MAX sizeof (((struct sockaddr_un *) 0)->sun_path)
+#ifndef UNIX_PATH_MAX
+#define UNIX_PATH_MAX G_SIZEOF_MEMBER (struct sockaddr_un, sun_path)
+#endif
 
 struct _GUnixSocketAddressPrivate
 {
